package main

import (
	"github.com/stretchr/testify/assert"
	"keentune/daemon/common/config"
	m "keentune/daemon/modules"
	"testing"
)

func InitFileTest() {
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.Home = "/etc/keentune/keentuned"
	config.KeenTune.DumpHome = "/var/keentune/keentuned"
}

func Test_checkTrainingFlags(t *testing.T) {
	InitFileTest()
	var (
		cmdName = "sensitize"
		trainF  = TrainFlag{
			Job:    "bbb",
			Data:   "aaa",
			Trials: 3,
			Force:  false,
			Log:    "/var/log/keentune/bbb.log",
		}
	)

	err := checkTrainingFlags(cmdName, &trainF)
	assert.NotNil(t, err)
}

func TestIsMutexJobRunning(t *testing.T) {
	InitFileTest()
	expected := false
	ret := IsMutexJobRunning(m.JobTuning)
	assert.Equal(t, expected, ret)
}

func Test_checkData(t *testing.T) {
	InitFileTest()
	var (
		name = "aaa"
	)

	err := checkData(name)
	assert.NotNil(t, err)
}

func Test_isTuneDataReady(t *testing.T) {
	InitFileTest()
	var (
		name     = "aaa"
		reason   = new(string)
		expected = false
	)

	ready := isTuneDataReady(name, reason)
	assert.Equal(t, expected, ready)
}

func Test_checkTuningFlags(t *testing.T) {
	InitFileTest()
	var (
		name = "tune"
		flag = &TuneFlag{
			Name:    "aaa",
			Round:   10,
			Verbose: false,
			Log:     "/var/log/keentune/aaa.log",
		}
	)

	err := checkTuningFlags(name, flag)
	assert.Nil(t, err)
}

func Test_parseJobRunningErrMsg(t *testing.T) {
	var (
		msg      = "tuning aaa"
		expected = "Another tuning job aaa is running, use 'keentune param stop' to shutdown."
	)

	errMsg := parseJobRunningErrMsg(msg)
	assert.Equal(t, expected, errMsg)
}

func Test_checkJob(t *testing.T) {
	var (
		cmd  = "sensitize"
		name = "abb"
	)

	err := checkJob(cmd, name)
	assert.Nil(t, err)
}

func Test_matchRegular(t *testing.T) {
	var (
		str = "abc_ef12"
	)

	err := matchRegular(str)
	assert.Nil(t, err)
}

func Test_isJobRepeatOrHasRunningJob(t *testing.T) {
	var (
		cmd      = "tune"
		name     = "abb"
		reason   = new(string)
		expected = false
	)

	ret := isJobRepeatOrHasRunningJob(cmd, name, reason)
	assert.Equal(t, expected, ret)
}

func Test_getDeleteCmd(t *testing.T) {
	var (
		name     = "profile"
		expected = "keentune profile delete"
	)

	cmd := getDeleteCmd(name)
	assert.Equal(t, expected, cmd)
}

