package main

import (
	"fmt"
	"github.com/spf13/cobra"
	"github.com/stretchr/testify/assert"
	"os"
	"strings"
	"testing"
)

func Test_subCommands(t *testing.T) {
	got := subCommands()
	assert.NotNil(t, got)
}

func Test_initCmd(t *testing.T) {
	got := initCmd()
	assert.NotNil(t, got)
}

func Test_createRollbackAllCmd(t *testing.T) {
	got := createRollbackAllCmd()
	assert.NotNil(t, got)
}

func Test_rollbackCmd(t *testing.T) {
	parentCmd := "param"
	got := rollbackCmd(parentCmd)
	assert.NotNil(t, got)
}

func Test_setTuneFlag(t *testing.T) {
	var (
		flag TuneFlag
		cmd  = &cobra.Command{
			Use:     "tune",
			Short:   "Deploy and start a parameter tuning job",
			Long:    "Deploy and start a parameter tuning job",
			Example: egTune,
			Run: func(cmd *cobra.Command, args []string) {
				if strings.Trim(flag.Name, " ") == "" {
					fmt.Printf("%v Incomplete or Unmatched command.\n\n", ColorString("red", "[ERROR]"))
					cmd.Usage()
					os.Exit(1)
				}

				initWorkDirectory()
				if err := checkTuningFlags("tune", &flag); err != nil {
					fmt.Printf("%v check input: %v\n", ColorString("red", "[ERROR]"), err)
					os.Exit(1)
				}

				flag.Log = fmt.Sprintf("%v/%v.log", "/var/log/keentune", flag.Name)

				RunTuneRemote(flag)
			},
		}
	)

	setTuneFlag(cmd, &flag)
	assert.Nil(t, nil)
}

func Test_stopCmd(t *testing.T) {
	flag := "param"
	got := stopCmd(flag)
	assert.NotNil(t, got)
}

func Test_benchCmd(t *testing.T) {
	got := benchCmd()
	assert.NotNil(t, got)
}

func Test_newRootCmd(t *testing.T) {
	got := newRootCmd()
	assert.NotNil(t, got)
}

func Test_decorateCmd(t *testing.T) {
	var (
		cmd = createSensitizeCmds()
	)

	got := decorateCmd(cmd)
	assert.NotNil(t, got)
}

func TestColorString(t *testing.T) {
	want := "\u001B[1;40;32mok\u001B[0m"
	ret := ColorString("green", "ok")
	assert.Equal(t, want, ret)
}

func TestIsTuningJobFinish(t *testing.T) {
	var (
		job      = "aaa"
		status   = new(string)
		expected = false
	)

	InitFileTest()

	finish := IsTuningJobFinish(job, status)
	assert.Equal(t, expected, finish)
}
