/*
* Copyright (c) 2021-2023 Alibaba Cloud Computing Ltd.
* SPDX-License-Identifier: MulanPSL-2.0

* Package main for cli, the package implements all the command-line functions of keentune, including dynamic and static tuning, sensitive parameter recognition. Determine whether the command-line parameters are compliant.
 */
package main

import (
	"os"
)

const template = `{{with (or .Long .Short)}}{{. | trimTrailingWhitespaces}}{{end}}

Usage:{{if .Runnable}}
  {{.UseLine}}{{end}}{{if .HasAvailableSubCommands}}{{end}} {{if gt (len .Aliases) 0}}

Aliases:
  {{.NameAndAliases}}{{end}}{{if .HasExample}}

Examples:
{{.Example}}{{end}}{{if .HasAvailableSubCommands}}

Available Commands:{{range .Commands}}{{if (or .IsAvailableCommand)}}
  {{rpad .Name .NamePadding }} {{.Short}}{{end}}{{end}}{{end}}{{if .HasAvailableLocalFlags}}

Flags:
{{.LocalFlags.FlagUsages | trimTrailingWhitespaces}}{{end}}{{if .HasAvailableInheritedFlags}}

Global Flags:
{{.InheritedFlags.FlagUsages | trimTrailingWhitespaces}}{{end}}{{if .HasHelpSubCommands}}

Additional help topics:{{range .Commands}}{{if .IsAdditionalHelpTopicCommand}}
  {{rpad .CommandPath .CommandPathPadding}} {{.Short}}{{end}}{{end}}{{end}}{{if .HasAvailableSubCommands}}

Use "{{.CommandPath}} [command] --help" for more information about a command.{{end}}
`

func main() {
	rootCmd := newRootCmd()
	decorateCmd(rootCmd)
	rootCmd.SetHelpTemplate(template)
	rootCmd.AddCommand(subCommands()...)

	if err := rootCmd.Execute(); err != nil {
		os.Exit(1)
	}
}
