/*
* Copyright (c) 2021-2023 Alibaba Cloud Computing Ltd.
* SPDX-License-Identifier: MulanPSL-2.0

* Package common for daemon, this package contains the common, handle, heartbeat for common function. The variables required for the dynamic and static tuning function are defined, including state detection of the keentuned service and heartbeat packet detection for the other three components.
 */

package common

import (
	"github.com/stretchr/testify/assert"
	"keentune/daemon/common/config"
	"testing"
)

func TestIsDataReady(t *testing.T) {
	InitNodesTest()
	ret := IsDataReady("aaa")
	expected := false
	assert.Equal(t, expected, ret)
}

func TestGetAVLDataAndAlgo(t *testing.T) {
	InitNodesTest()
	_, _, _, err := GetAVLDataAndAlgo()
	assert.Nil(t, err)
}

func TestKeenTunedService(t *testing.T) {
	// InitNodesTest()
	// config.KeenTune.Port = "8888"
	// quit := make(chan os.Signal, 1)
	// go KeenTunedService(quit)
	// assert.Nil(t, nil)
}

func TestRunDelete(t *testing.T) {
	input := DeleteFlag{
		Name:  "aaa",
		Cmd:   "param",
		Force: true,
	}

	reply := new(string)
	err := RunDelete(input, reply)
	assert.Nil(t, err)
}

func TestRunTrainDelete(t *testing.T) {
	input := DeleteFlag{
		Name: "aaa",
	}

	reply := new(string)
	InitNodesTest()
	err := RunTrainDelete(input, reply)
	assert.Nil(t, err)
}

func Test_deleter_check(t *testing.T) {
	d := new(deleter)
	d.cmd = "param"
	d.fileName = "/var/keentune/keentuned/tuning_workspace/aaa"
	InitNodesTest()
	err := d.check("aaa")
	assert.Nil(t, err)
}

func Test_deleter_delete(t *testing.T) {
	d := new(deleter)
	d.cmd = "param"
	d.fileName = "/var/keentune/keentuned/tuning_workspace/aaa"
	err := d.delete()
	assert.Nil(t, err)
}

func TestGetParameterPath(t *testing.T) {
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.Home = "/etc/keentune/keentuned"
	config.KeenTune.DumpHome = "/var/keentune/keentuned"
	ret := GetParameterPath("aaa")
	assert.Empty(t, ret)
}

func TestGetSensitizePath(t *testing.T) {
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.Home = "/etc/keentune/keentuned"
	config.KeenTune.DumpHome = "/var/keentune/keentuned"
	ret := GetSensitizePath("aaa")
	assert.Empty(t, ret)
}

func TestIsApplying(t *testing.T) {
	ret := IsApplying()
	expected := false
	assert.Equal(t, expected, ret)
}

func TestResetJob(t *testing.T) {
	ResetJob()
	assert.Nil(t, nil)
}

func TestGetAVLDomain(t *testing.T) {
	InitNodesTest()
	ip := "localhost"
	port := "9873"
	_, err := GetAVLDomain(ip, port)
	assert.Equal(t, nil, err)
}

func TestGetStatus(t *testing.T) {
	InitNodesTest()
	ip := "localhost"
	port := "9873"
	ret := GetStatus(ip, port)
	assert.Nil(t, ret)
}

func Test_pingAndConnect(t *testing.T) {
	InitNodesTest()
	ip := "localhost"
	port := "9873"
	uri := "status"
	_, err := pingAndConnect(ip, port, uri)
	assert.Nil(t, err)
}

func TestGetAVLAgentAddr(t *testing.T) {
	InitNodesTest()
	ip := "localhost"
	port := "9874"
	agent := "localhost"
	_, _, err := GetAVLAgentAddr(ip, port, agent)
	assert.Nil(t, err)
}
