package common

import (
	"io/ioutil"
	"net/http/httptest"
	"strings"
	"testing"

	"github.com/stretchr/testify/assert"
)

func Test_write(t *testing.T) {
	InitNodesTest()

	info := `{"name": "aaa.conf",
			"info": "hello world"
}`

	req := httptest.NewRequest("POST", "http://localhost:9871/write", strings.NewReader(info))
	w := httptest.NewRecorder()

	write(w, req)
	byteInfo, err := ioutil.ReadAll(w.Result().Body)
	assert.Nil(t, err)

	want := `{"suc": true, "msg": "write file 'aaa.conf' successfully."}`
	assert.Equal(t, want, string(byteInfo))
}

func Test_registerRouter(t *testing.T) {
	registerRouter()
	assert.Nil(t, nil)
}

func Test_getFullPath(t *testing.T) {
	InitFileTest()
	ret := getFullPath("aaa.conf")
	assert.NotEmpty(t, ret)
}

func Test_handler(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	info := `{
	"data": {
		"sysctl": {			
			"vm.page-cluster": {
				"suc": true,
				"msg": ""
			},
			"vm.stat_interval": {
				"suc": true,
				"msg": ""
			},
			"vm.swappiness": {
				"suc": true,
				"msg": ""
			}
		}
	},
	"target_id": 1
}`

	req := httptest.NewRequest("POST", "http://localhost:9871/apply_result", strings.NewReader(info))
	w := httptest.NewRecorder()

	handler(w, req)
	byteInfo, err := ioutil.ReadAll(w.Result().Body)
	assert.Nil(t, err)

	want := `{"suc": true, "msg": ""}`
	assert.Equal(t, want, string(byteInfo))
}

func Test_report(t *testing.T) {
	url := "apply_result"
	value := `{
	"data": {
		"sysctl": {			
			"vm.page-cluster": {
				"suc": true,
				"msg": ""
			},
			"vm.stat_interval": {
				"suc": true,
				"msg": ""
			},
			"vm.swappiness": {
				"suc": true,
				"msg": ""
			}
		}
	},
	"target_id": 1`
	var err error
	report(url, []byte(value), err)
	assert.Nil(t, nil)
}

func Test_status(t *testing.T) {
	InitNodesTest()

	req := httptest.NewRequest("GET",
		"http://localhost:9871/status",
		nil,
	)
	w := httptest.NewRecorder()

	status(w, req)
	byteInfo, err := ioutil.ReadAll(w.Result().Body)
	assert.Nil(t, err)

	want := `{"status": "alive"}`
	assert.Equal(t, want, string(byteInfo))
}

func Test_command(t *testing.T) {
	InitNodesTest()

	info := `{"cmd": "keentune sensitize jobs"}`

	req := httptest.NewRequest("POST", "http://localhost:9871/cmd", strings.NewReader(info))
	w := httptest.NewRecorder()

	command(w, req)
	_, err := ioutil.ReadAll(w.Result().Body)
	assert.Nil(t, err)
}

func Test_execCmd(t *testing.T) {
	inputCmd := "keentune param -h"
	result := new(string)
	err := execCmd(inputCmd, result)
	assert.Nil(t, err)
}

func Test_getMsg(t *testing.T) {
	org := `{"suc":true,"msg":"[OK] KeenTune Init success"}`
	cmd := "keentune init"
	expected := `{'suc':true,'msg':'[OK] KeenTune Init success'}`
	msg := getMsg(org, cmd)
	assert.Equal(t, expected, msg)
}

func Test_getCmd(t *testing.T) {
	req := `{"cmd": "keentune sensitize jobs"}`
	info := strings.NewReader(req)
	body := ioutil.NopCloser(info)

	got, err := getCmd(body)
	assert.NotEmpty(t, got)
	assert.Nil(t, err)
}
