package common

import (
	"keentune/daemon/common/config"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
)

func TestIsBenchOffline(t *testing.T) {
	config.KeenTune = new(config.KeentunedConf)
	var benchGp []config.BenchGroup
	benchGp = append(benchGp, config.BenchGroup{
		SrcPort: "9874",
		SrcIPs:  []string{"localhost"},
	})
	config.KeenTune.BenchGroup = benchGp
	ret := IsBenchOffline(new(string))
	assert.Equal(t, false, ret)
}

func TestHeartbeatCheck(t *testing.T) {
	InitNodesTest()
	config.ProgramNeedExit <- true
	err := HeartbeatCheck()
	assert.Nil(t, err)
}

func Test_monitorClientStatus(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	reply := new(string)
	gp := []bool{
		true,
	}

	config.ProgramNeedExit <- true
	go monitorClientStatus(IsClientOffline, reply, gp)
	time.Sleep(3 * time.Second)
	assert.Nil(t, nil)
}

func Test_monitorImply(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	reply := new(string)
	gp := []bool{
		true,
	}
	ret := monitorImply(IsClientOffline, reply, gp)
	expected := false
	assert.Equal(t, expected, ret)
}

func TestIsClientOffline(t *testing.T) {
	InitNodesTest()
	reply := new(string)
	ret := IsClientOffline(reply)
	expected := false
	assert.Equal(t, expected, ret)
}

func TestIsTargetOffline(t *testing.T) {
	InitNodesTest()
	reply := new(string)
	ret := IsTargetOffline(reply)
	expected := false
	assert.Equal(t, expected, ret)
}

func TestStartCheck(t *testing.T) {
	InitNodesTest()
	_, _, err := StartCheck()
	assert.Nil(t, err)
}

func Test_checkBrain(t *testing.T) {
	type args struct {
		warningInfo *[]string
		okInfo      *string
		domains     []string
	}
	tests := []struct {
		name string
		args args
	}{
		// TODO: Add test cases.
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			checkBrain(tt.args.warningInfo, tt.args.okInfo, tt.args.domains)
		})
	}
}

func Test_checkBenchAndDest(t *testing.T) {
	type args struct {
		warningInfo *[]string
		okInfo      *string
	}
	tests := []struct {
		name string
		args args
	}{
		// TODO: Add test cases.
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			checkBenchAndDest(tt.args.warningInfo, tt.args.okInfo)
		})
	}
}

func Test_checkTarget(t *testing.T) {
	type args struct {
		domains     *[]string
		warningInfo *[]string
		okInfo      *string
	}
	tests := []struct {
		name string
		args args
	}{
		// TODO: Add test cases.
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			checkTarget(tt.args.domains, tt.args.warningInfo, tt.args.okInfo)
		})
	}
}

func TestIsBrainOffline(t *testing.T) {
	reply := new(string)
	InitNodesTest()
	got := IsBrainOffline(reply)
	assert.Equal(t, false, got)
}

func Test_checkSettableTarget(t *testing.T) {
	type args struct {
		group []bool
	}
	tests := []struct {
		name    string
		args    args
		wantErr bool
	}{
		// TODO: Add test cases.
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			if err := checkSettableTarget(tt.args.group); (err != nil) != tt.wantErr {
				t.Errorf("checkSettableTarget() error = %v, wantErr %v", err, tt.wantErr)
			}
		})
	}
}

func TestIsSetTargetOffline(t *testing.T) {
	InitNodesTest()
	gp := []bool{true}
	reply := new(string)
	got := IsSetTargetOffline(gp, reply)
	assert.Equal(t, false, got)
}

func TestCheckBrainClient(t *testing.T) {
	InitNodesTest()
	config.ServeTerminate <- true
	err := CheckBrainClient()
	time.Sleep(3 * time.Second)
	assert.Nil(t, err)
}
