package common

import (
	"io/ioutil"
	"keentune/daemon/common/config"
	"net/http/httptest"
	"strings"
	"testing"

	"github.com/stretchr/testify/assert"
)

func Test_read(t *testing.T) {
	InitNodesTest()
	testReadParam(t)
	testReadTargetConf(t)
}

func testReadParam(t *testing.T) {
	info := `{"name": "aaa",
			"type": "param-bench"
			}`

	req := httptest.NewRequest("POST", "http://localhost:9871/read", strings.NewReader(info))
	w := httptest.NewRecorder()

	read(w, req)
	byteInfo, err := ioutil.ReadAll(w.Result().Body)
	assert.Nil(t, err)

	want := `{"suc": false, "msg": "job 'aaa' does not exist"}`
	// want := `{"suc": true, "msg": {"parameters":"target-group-1: /etc/keentune/keentuned/parameter/sysctl.json","benchmark":"/etc/keentune/keentuned/benchmark/wrk/wrk_http_long.json"}}`
	assert.Equal(t, want, string(byteInfo))
}

func testReadTargetConf(t *testing.T) {
	var group []config.Group
	group = append(group, config.Group{
		IPs: []string{
			"1.2.3.4",
			"localhost",
		},
		GroupNo: 1,
	})
	config.KeenTune.Target.Group = group

	info := `{"type": "target-group"}`

	req := httptest.NewRequest("POST", "http://localhost:9871/read", strings.NewReader(info))
	w := httptest.NewRecorder()

	read(w, req)
	byteInfo, err := ioutil.ReadAll(w.Result().Body)
	assert.Nil(t, err)

	want := `{"suc": true, "msg": "[target-group-1]\nTARGET_IP = 1.2.3.4,localhost\n"}`
	assert.Equal(t, want, string(byteInfo))

}

func Test_readParamAndBenchConf(t *testing.T) {
	var (
		job    = "05_04"
		result = new(string)
	)

	InitFileTest()

	err := readParamAndBenchConf(job, result)
	assert.Nil(t, err)
}

func Test_readTargetGroup(t *testing.T) {
	var (
		grep   = ""
		result = new(string)
	)
	InitNodesTest()
	err := readTargetGroup(grep, result)
	assert.Nil(t, err)
}

func Test_readTrainInfo(t *testing.T) {
	var (
		job    = "05_04"
		result = new(string)
	)
	InitFileTest()

	err := readTrainInfo(job, result)
	assert.NotNil(t, err)
}

func Test_readTuneInfo(t *testing.T) {
	var (
		job    = "05_04"
		result = new(string)
	)
	InitFileTest()

	err := readTuneInfo(job, result)
	assert.Nil(t, err)
}
