package common

import (
	"keentune/daemon/common/config"
	"keentune/daemon/common/log"
	"keentune/daemon/common/utils"
)

func InitHttpChan() {
	config.IsInnerBenchRequests = make([]bool, 4)
	config.IsInnerApplyRequests = make([]bool, 4)
	config.IsInnerSensitizeRequests = make([]bool, 4)

	config.ApplyResultChan = make([]chan []byte, 4)
	config.ApplyResultChan[1] = make(chan []byte, 1)

	config.BenchmarkResultChan = make([]chan []byte, 4)
	config.BenchmarkResultChan[1] = make(chan []byte, 1)

	config.ProgramNeedExit = make(chan bool, 1)

	config.ServeTerminate = make(chan bool, 1)
	config.ClientOffline = make(chan bool, 1)
	config.SensitizeResultChan = make(chan []byte, 1)
}

func InitNodesTest() {
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.LogFileLvl = "DEBUG"
	config.KeenTune.FileName = "keentuned.log"
	config.KeenTune.Interval = 7
	config.KeenTune.BackupCount = 14
	config.KeenTune.Home = "/etc/keentune/keentuned"
	config.KeenTune.DumpHome = "/var/keentune/keentuned"
	log.Init()

	InitBenchTest()
	InitTargetTest()
	config.KeenTune.BrainPort = "9872"
	config.KeenTune.BrainIP = "localhost"
	config.KeenTune.HeartbeatTime = 3
	config.KeenTune.SensTimeout = 1
	config.KeenTune.TargetSetTimeout = 1
	config.KeenTune.BenchTimeout = 1
	ip, _ := utils.GetExternalIP()
	config.RealLocalIP = ip
	config.KeenTune.Port = "9871"
}

func InitBenchTest() {
	var benchGp []config.BenchGroup
	benchGp = append(benchGp, config.BenchGroup{
		SrcPort:   "9874",
		SrcIPs:    []string{"localhost"},
		DestIP:    "localhost",
		BenchConf: "benchmark/wrk/wrk_http_long.json",
	})

	bencIpMap := map[string]int{
		"localhost": 1,
	}
	config.KeenTune.Bench = config.Bench{
		BenchGroup: benchGp,
		BenchIPMap: bencIpMap,
	}
}
func InitTargetTest() {
	targetGp := config.Target{
		Group: []config.Group{
			{
				IPs:     []string{"localhost"},
				Port:    "9873",
				GroupNo: 1,
			},
		},
		IPMap: map[string]int{
			"localhost": 1,
		},
	}

	config.KeenTune.Target = targetGp
}

func InitFileTest() {
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.Home = "/etc/keentune/keentuned"
	config.KeenTune.DumpHome = "/var/keentune/keentuned"
}
