/*
* Copyright (c) 2021-2023 Alibaba Cloud Computing Ltd.
* SPDX-License-Identifier: MulanPSL-2.0
 */
package param

import (
	"fmt"
	com "keentune/daemon/api/common"
	"keentune/daemon/common/log"
	m "keentune/daemon/modules"
	"strings"
)

// Rollback run param rollback service
func (s *Service) Rollback(flag com.RollbackFlag, reply *string) error {
	if com.IsApplying() {
		return fmt.Errorf("operation does not support, job %v is running", m.GetRunningTask())
	}

	defer func() {
		*reply = log.ClientLogMap[log.ParamRollback]
		log.ClearCliLog(log.ParamRollback)
	}()

	detail, err := m.Rollback(log.ParamRollback, "param")
	if err != nil {
		return fmt.Errorf("%v", detail)
	}

	if strings.Contains(detail, "No Need to Rollback") {
		log.Warn(log.ParamRollback, detail)
		return nil
	}

	log.Infof(log.ParamRollback, fmt.Sprintf("[ok] %v rollback finished: %v", flag.Cmd, detail))
	return nil
}
