/*
* Copyright (c) 2021-2023 Alibaba Cloud Computing Ltd.
* SPDX-License-Identifier: MulanPSL-2.0

* Package param for daemon, this package contains the delete, dump, job, list, rollback, stop, tune for dynamic tuning. Is a function implementation of the dynamic tuning server in the rpc framework.
 */

package param

import (
	com "keentune/daemon/api/common"
	"keentune/daemon/common/config"
	"keentune/daemon/common/file"
	m "keentune/daemon/modules"
	"os"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
)

func TestService_Tune(t *testing.T) {
	s := &Service{}
	flag := TuneFlag{
		Name:  "aaa",
		Round: 10,
		Log:   "/var/log/keentune/aaa.log",
	}
	reply := new(string)
	com.InitNodesTest()
	com.InitHttpChan()

	clearTuneJob()
	config.ProgramNeedExit <- true
	err := s.Tune(flag, reply)
	assert.Nil(t, err)
	time.Sleep(3 * time.Second)
	clearTuneJob()
}

func Test_runTuning(t *testing.T) {
	flag := TuneFlag{
		Name:  "aaa",
		Round: 10,
		Log:   "/var/log/keentune/aaa.log",
	}
	com.InitNodesTest()
	com.InitHttpChan()
	clearTuneJob()
	go runTuning(flag)
	assert.Nil(t, nil)
	clearTuneJob()
}

func TestTuningImpl(t *testing.T) {
	flag := TuneFlag{
		Name:  "aaa",
		Round: 10,
		Log:   "/var/log/keentune/aaa.log",
	}
	com.InitNodesTest()
	com.InitHttpChan()
	config.KeenTune.BenchGroup[0].BenchConf = "wrk_http_long.json"
	config.KeenTune.HeartbeatTime = 3
	clearTuneJob()

	err := TuningImpl(flag, "tuning")
	assert.Nil(t, err)
	clearTuneJob()
}

func TestGetBenchmarkInst(t *testing.T) {
	benchFile := "wrk_http_long.json"
	com.InitFileTest()
	com.InitNodesTest()
	_, err := GetBenchmarkInst(benchFile)
	assert.Nil(t, err)
}

func Test_sortBenchItemNames(t *testing.T) {
	items := map[string]m.ItemDetail{
		"aaa": {},
		"bbb": {},
	}

	got := sortBenchItemNames(items)
	assert.NotNil(t, got)
}

func clearTuneJob() {
	os.RemoveAll("/var/keentune/keentuned/tuning_workspace/aaa")
	file.DeleteRow(config.GetDumpPath(config.TuneCsv), "aaa", m.TuneNameIdx)
	os.Remove("/var/log/keentune/aaa.log")
	m.ClearTask()
}
