package profile

import (
	"keentune/daemon/api/common"
	"keentune/daemon/common/config"
	m "keentune/daemon/modules"
	"sync"
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestSetDefault(t *testing.T) {
	common.InitNodesTest()
	common.InitHttpChan()
	config.KeenTune.TargetSetTimeout = 1
	SetDefault()
	assert.Nil(t, nil)
}

func Test_setConfigure(t *testing.T) {
	var (
		setter = setVars{
			ip:     "localhost",
			wg:     &sync.WaitGroup{},
			target: config.Group{},
			param: []map[string]map[string]string{
				{
					"aaa": map[string]string{
						"isok": "ok",
					},
				},
			},
		}
		domains = new(sync.Map)
	)
	common.InitNodesTest()
	common.InitHttpChan()
	setter.wg.Add(1)
	config.KeenTune.TargetSetTimeout = 1
	go setConfigure(setter, domains)
	assert.Nil(t, nil)
}

func Test_getSuitableConf(t *testing.T) {
	var (
		setter = setVars{
			ip:     "localhost",
			wg:     &sync.WaitGroup{},
			target: config.Group{},
			param: []map[string]map[string]string{
				{
					"aaa": map[string]string{
						"isok": "ok",
					},
				},
			},
		}
		tuner = &m.Tuner{
			Setter: m.Setter{
				Group:    []bool{true},
				ConfFile: []string{"cpu_high_load.conf"},
			},
		}
	)

	_, ret := getSuitableConf(setter, tuner)
	assert.Equal(t, true, ret)
}

func Test_getActiveConf(t *testing.T) {
	var (
		groupNo int
		ip      = "localhost"
	)

	got := getActiveConf(groupNo, ip)
	assert.NotNil(t, got)
}

func Test_tryConnect(t *testing.T) {
	common.InitNodesTest()
	common.InitNodesTest()
	config.KeenTune.TargetSetTimeout = 1
	ip := "localhost"
	port := "9873"
	ret := tryConnect(ip, port)
	assert.Equal(t, true, ret)
}
