/*
* Copyright (c) 2021-2023 Alibaba Cloud Computing Ltd.
* SPDX-License-Identifier: MulanPSL-2.0

* Package sensitize for daemon, this package contains the collect, delete, list, stop, train for sensitize parameter collection. Is a function implementation of the sensitize parameter collection server in the rpc framework.
 */

package sensitize

import (
	"github.com/stretchr/testify/assert"
	com "keentune/daemon/api/common"
	"keentune/daemon/common/config"
	"keentune/daemon/common/file"
	m "keentune/daemon/modules"
	"os"
	"testing"
)

func TestService_Train(t *testing.T) {
	var (
		flags = TrainFlag{
			Job:    "bbb",
			Data:   "aaa",
			Trials: 3,
			Force:  true,
			Log:    "/var/log/keentune/keentune_train_bbb.log",
		}

		reply = new(string)
	)
	com.InitNodesTest()
	com.InitHttpChan()
	s := &Service{}
	err := s.Train(flags, reply)
	assert.NotNil(t, err)
}

func Test_runTrain(t *testing.T) {
	flags := TrainFlag{
		Job:    "bbb",
		Data:   "aaa",
		Trials: 3,
		Force:  true,
		Log:    "/var/log/keentune/keentune_train_bbb.log",
	}
	com.InitNodesTest()
	com.InitHttpChan()
	go runTrain(flags)
	assert.Nil(t, nil)
}

func TestTrainImpl(t *testing.T) {
	defer clearJob()
	var (
		flag = TrainFlag{
			Job:    "bbb",
			Data:   "aaa",
			Trials: 3,
			Force:  true,
			Log:    "/var/log/keentune/keentune_train_bbb.log",
		}

		cmd = "sensitize"
	)
	com.InitNodesTest()
	com.InitHttpChan()

	os.RemoveAll("/var/keentune/keentuned/sensitize_workspace/bbb")
	file.DeleteRow(config.GetDumpPath(config.SensitizeCsv), flag.Job, m.TrainNameIdx)
	os.Remove(flag.Log)
	config.KeenTune.HeartbeatTime = 3
	config.KeenTune.SensTimeout = 3
	err := TrainImpl(flag, cmd)
	assert.Nil(t, err)
}

func clearJob() {
	os.RemoveAll("/var/keentune/keentuned/sensitize_workspace/bbb")
	file.DeleteRow(config.GetDumpPath(config.SensitizeCsv), "bbb", m.TrainNameIdx)
	os.Remove("/var/log/keentune/keentune_train_bbb.log")
}
