package system

import (
	"github.com/stretchr/testify/assert"
	com "keentune/daemon/api/common"
	"keentune/daemon/common/config"
	"sync"
	"testing"
)

func TestService_Init(t *testing.T) {
	com.InitNodesTest()
	s := &Service{}
	ret := s.Init("", new(string))
	assert.Nil(t, ret)
}

func Test_initialize(t *testing.T) {
	com.InitNodesTest()
	_, err := initialize()
	assert.Nil(t, err)
}

func Test_checkBrainAVL(t *testing.T) {
	var (
		scWg          = new(sync.WaitGroup)
		ymlConf       = new(keenTuneYML)
		warningDetail = new(string)
	)
	scWg.Add(1)
	com.InitNodesTest()
	checkBrainAVL(scWg, ymlConf, warningDetail)
	assert.Nil(t, nil)
}

func Test_getYMLConf(t *testing.T) {
	var (
		conf  = new(keenTuneYML)
		group = make([][]ymlTarget, 2)
	)
	got := getYMLConf(conf, group)
	assert.NotNil(t, got)
}

func Test_checkTargetAVL(t *testing.T) {
	var (
		scWg          = new(sync.WaitGroup)
		group         = make([][]ymlTarget, 2)
		warningDetail = new(string)
	)
	scWg.Add(1)
	com.InitNodesTest()
	group[0] = make([]ymlTarget, 2)
	checkTargetAVL(scWg, warningDetail, &group)
	assert.Nil(t, nil)
}

func Test_accessTarget(t *testing.T) {
	var (
		wg            = new(sync.WaitGroup)
		warningDetail = make([]string, 2)
		target        config.Group
		targetGroup   = make([][]ymlTarget, 2)
		groupIdx      int
		ip            = "localhost"
		ipIdx         int
	)

	wg.Add(1)
	com.InitNodesTest()
	targetGroup[0] = make([]ymlTarget, 2)
	go accessTarget(wg, warningDetail, target, &targetGroup, groupIdx, ip, ipIdx)
	assert.Nil(t, nil)
}

func Test_checkBenchAVL(t *testing.T) {
	com.InitNodesTest()
	var (
		scWg          = &sync.WaitGroup{}
		ymlConf       = new(keenTuneYML)
		warningDetail = new(string)
	)

	scWg.Add(1)
	com.InitNodesTest()
	go checkBenchAVL(scWg, ymlConf, warningDetail)
	assert.Nil(t, nil)
}

func Test_accessBench(t *testing.T) {
	var (
		wg           = new(sync.WaitGroup)
		accessResult = make([]string, 4)
		bench        config.BenchGroup
		ymlBch       = make([]ymlBench, 2)
		ip           = "localhost"
	)

	wg.Add(1)
	com.InitNodesTest()
	bench = config.KeenTune.BenchGroup[0]
	config.KeenTune.BenchIPMap["localhost"] = 1
	go accessBench(ymlBch, wg, bench, ip, accessResult)
	assert.Nil(t, nil)
}
