package config

import (
	"github.com/go-ini/ini"
	"github.com/stretchr/testify/assert"
	"strings"
	"testing"
)

func TestUpdateKeentunedConf(t *testing.T) {
	InitFileTest()
	var (
		info = "[brain]\\n\\n          AUTO_TUNING_ALGORITHM   = Hord\\n\\n          [keentuned]\\n\\n          BASELINE_BENCH_ROUND    = 1\\n\\n          TUNING_BENCH_ROUND      = 1\\n\\n          RECHECK_BENCH_ROUND     = 1"
	)

	_, err := UpdateKeentunedConf(info)
	assert.Nil(t, err)
}

func Test_compareCfg(t *testing.T) {
	InitFileTest()
	var (
		info = "[brain]\\n\\n          AUTO_TUNING_ALGORITHM   = Hord\\n\\n          [keentuned]\\n\\n          BASELINE_BENCH_ROUND    = 1\\n\\n          TUNING_BENCH_ROUND      = 1\\n\\n          RECHECK_BENCH_ROUND     = 1"
	)
	cfg, usercfg, err := loadCfg(info)
	assert.Nil(t, err)
	compareCfg(cfg, usercfg)
	assert.Nil(t, nil)
}

func Test_loadCfg(t *testing.T) {
	InitFileTest()
	var (
		info = "[brain]\\n\\n          AUTO_TUNING_ALGORITHM   = Hord\\n\\n          [keentuned]\\n\\n          BASELINE_BENCH_ROUND    = 1\\n\\n          TUNING_BENCH_ROUND      = 1\\n\\n          RECHECK_BENCH_ROUND     = 1"
	)
	_, _, err := loadCfg(info)
	assert.Nil(t, err)
}

func Test_setCfg(t *testing.T) {
	InitFileTest()
	var (
		info = "[brain]\\n\\n          AUTO_TUNING_ALGORITHM   = Hord\\n\\n          [keentuned]\\n\\n          BASELINE_BENCH_ROUND    = 1\\n\\n          TUNING_BENCH_ROUND      = 1\\n\\n          RECHECK_BENCH_ROUND     = 1"
	)
	cfg, usercfg, err := loadCfg(info)
	assert.Nil(t, err)

	details := strings.Split(info, "\n")

	ret := setCfg(details, cfg, usercfg)
	assert.Empty(t, ret)
}

func Test_checkInitGroup(t *testing.T) {
	cfg, _ := ini.InsensitiveLoad(keentuneConfigFile)
	err := checkInitGroup(cfg)
	assert.Nil(t, err)
}

func TestReloadConf(t *testing.T) {
	ReloadConf()
	assert.Nil(t, nil)
}

func TestCheckAndReloadConf(t *testing.T) {
	err := CheckAndReloadConf()
	assert.Nil(t, err)
}

func TestGetRerunConf(t *testing.T) {
	_, err := GetRerunConf(keentuneConfigFile)
	assert.Nil(t, err)
}

