package config

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestGetTempPath(t *testing.T) {
	InitFileTest()
	path := GetTempPath("")
	assert.NotEmpty(t, path)
}

func TestGetGenerateWorkPath(t *testing.T) {
	InitFileTest()
	var name = "cpu_high_load.json"
	path := GetGenerateWorkPath(name)
	assert.NotEmpty(t, path)
}

func TestGetBenchHomePath(t *testing.T) {
	InitFileTest()
	path := GetBenchHomePath()
	assert.NotEmpty(t, path)
}

func TestGetProfileWorkPath(t *testing.T) {
	InitFileTest()
	path := GetProfileWorkPath("")
	assert.NotEmpty(t, path)
}

func TestGetDumpPath(t *testing.T) {
	InitFileTest()
	path := GetDumpPath(TuneCsv)
	assert.NotEmpty(t, path)
}

func TestGetTuningPath(t *testing.T) {
	InitFileTest()
	var name = "aaa"
	path := GetTuningPath(name)
	assert.NotEmpty(t, path)
}

func TestGetSensitizePath(t *testing.T) {
	InitFileTest()
	var name = "bbb"
	path := GetSensitizePath(name)
	assert.NotEmpty(t, path)
}

func TestGetSensitizeWorkPath(t *testing.T) {
	InitFileTest()
	var name = "bbb"
	path := GetSensitizeWorkPath(name)
	assert.NotEmpty(t, path)
}

func TestGetParamHomePath(t *testing.T) {
	InitFileTest()
	path := GetParamHomePath()
	assert.NotEmpty(t, path)
}

func TestGetProfileHomePath(t *testing.T) {
	InitFileTest()
	path := GetProfileHomePath("")
	assert.NotEmpty(t, path)
}

func TestGetSensitizeHomePath(t *testing.T) {
	InitFileTest()
	path := GetSensitizeHomePath("")
	assert.NotEmpty(t, path)
}

func TestGetDumpCSVPath(t *testing.T) {
	InitFileTest()
	path := GetDumpCSVPath()
	assert.NotEmpty(t, path)
}

func Test_assembleFilePath(t *testing.T) {
	var (
		empty     = ""
		absPath   = "/var/keentune/keentuned/profile/active.conf"
		relPath   = "profile/active.conf"
		fileName  = "active.conf"
		prefix    = "/var/keentune/keentuned"
		partition = "profile"
	)

	path1 := assembleFilePath(prefix, partition, empty)
	assert.NotEmpty(t, path1)

	path2 := assembleFilePath(prefix, partition, absPath)
	assert.NotEmpty(t, path2)

	path3 := assembleFilePath(prefix, partition, relPath)
	assert.NotEmpty(t, path3)

	path4 := assembleFilePath(prefix, partition, fileName)
	assert.NotEmpty(t, path4)
}

func TestGetAbsolutePath(t *testing.T) {
	var (
		fileName    = "sysctl.json"
		class       = "parameter"
		fileType    = ".json"
		extraSuffix = "_best.json"
	)
	InitFileTest()

	path := GetAbsolutePath(fileName, class, fileType, extraSuffix)
	assert.NotEmpty(t, path)
}

func TestGetBenchJsonPath(t *testing.T) {
	var name = "wrk_http_long.json"
	InitFileTest()
	path := GetBenchJsonPath(name)
	assert.NotEmpty(t, path)
}

func TestGetKeenTunedConfPath(t *testing.T) {
	var (
		nameEmpty = ""
		nameAbs   = "/etc/keentuned.conf"
		nameRel   = "conf/keentuned.conf"
	)

	InitFileTest()

	path := GetKeenTunedConfPath(nameEmpty)
	assert.NotEmpty(t, path)

	path1 := GetKeenTunedConfPath(nameAbs)
	assert.NotEmpty(t, path1)

	path2 := GetKeenTunedConfPath(nameRel)
	assert.NotEmpty(t, path2)

}

func TestGetProfilePath(t *testing.T) {
	var (
		homeFile    = "ecs-guest.conf"
		homeAbsFile = "/etc/keentune/keentuned/profile/ecs/ecs-guest.conf"
		workFile    = "ccc.conf"
	)
	InitFileTest()
	path := GetProfilePath(homeFile)
	assert.NotEmpty(t, path)

	path1 := GetProfilePath(homeAbsFile)
	assert.NotEmpty(t, path1)

	path2 := GetProfilePath(workFile)
	assert.Empty(t, path2)
}
