package file

import (
	"github.com/stretchr/testify/assert"
	"os"
	"testing"
)

func TestCreatCSV(t *testing.T) {
	var (
		filename = "aaa.csv"
		info     = []string{
			"name", "addr", "age",
		}
	)

	err := CreatCSV(filename, info)
	assert.Nil(t, err)
	os.Remove(filename)
}

func Test_addRecord(t *testing.T) {
	var (
		filename = "aaa.csv"
		info     = []string{
			"name", "addr", "age",
		}
	)

	err := addRecord(filename, info)
	assert.Nil(t, err)
}

func TestAppend(t *testing.T) {
	var (
		filename = "aaa.csv"
		info = []string{
			"lilei", "bj", "24",
		}
	)

	err := Append(filename, info)
	assert.Nil(t, err)
}

func TestInsert(t *testing.T) {
	var (
		filename = "aaa.csv"
		info     = []string{
			"hanhan", "cq", "43",
		}
		priKey = 0
	)

	err := Insert(filename, info, priKey)
	assert.Nil(t, err)
}

func TestUpdateRow(t *testing.T) {
	var (
		filename = "aaa.csv"
		info     = map[int]string{
			0: "hanhan",
			2: "34",
		}
		priKey = 0
	)

	err := UpdateRow(filename, priKey, info)
	assert.Nil(t, err)
}

func TestDeleteRow(t *testing.T) {
	var (
		filename = "aaa.csv"

		priKey = 0
		value  = "lilei"
	)

	err := DeleteRow(filename, value, priKey)
	assert.Nil(t, err)
}

func TestIsInSlice(t *testing.T) {
	var (
		value1 = "aaa"
		value2 = "c"
		pond   = []string{
			"aaa", "bbbb",
		}
	)

	ret1 := IsInSlice(value1, pond)
	assert.Equal(t, true, ret1)

	ret2 := IsInSlice(value2, pond)
	assert.Equal(t, false, ret2)
}

func TestHasRecord(t *testing.T) {
	var (
		filename = "aaa.csv"
		match    = "hanhan"
		priKey   = 0
	)
	ret := HasRecord(filename, match, priKey)
	assert.Equal(t, true, ret)
	os.Remove(filename)
}

func TestIsJobRunning(t *testing.T) {
	var (
		filename = "aaa.csv"
		head     = []string{
			"name", "addr", "age", "status",
		}

		info = []string{
			"lilei", "bj", "24", "running",			
		}
		statusKey = 3
		priVal    = "lilei"
		priKey    = 0
		expected  = true
	)

	CreatCSV(filename, head)
	Insert(filename, info)

	ret := IsJobRunning(filename, priVal, priKey, statusKey)
	assert.Equal(t, expected, ret)
}

func TestGetRecord(t *testing.T) {
	var (
		filename  = "aaa.csv"
		statusKey = 3
		priVal    = "lilei"
		priKey    = 0
		expected  = "running"
	)

	record := GetRecord(filename, priVal, priKey, statusKey)
	assert.Equal(t, expected, record)
}

func TestGetAllRecords(t *testing.T) {
	filename := "aaa.csv"
	ret, _ := GetAllRecords(filename)
	assert.NotNil(t, ret)
}

func TestGetOneRecord(t *testing.T) {
	var (
		filename = "aaa.csv"
		match    = "lilei"
		priKey   = 0
	)
	ret, _ := GetOneRecord(filename, match, priKey)
	assert.NotNil(t, ret)
}

func Test_truncWrite(t *testing.T) {
	var (
		filename = "aaa.csv"
		info     = [][]string{
			{
				"guangHua", "bj", "24", "error",
			},
		}
	)

	err := truncWrite(filename, info)
	assert.Nil(t, err)
	os.Remove(filename)
}

