package utils

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestCalculate(t *testing.T) {
	want := int64(7)
	ret, _ := Calculate("4+3")
	assert.Equal(t, want, ret)
}

func TestCalculateCondExp(t *testing.T) {
	want := true
	ret := CalculateCondExp("4>3 & 5>=4")
	assert.Equal(t, want, ret)

	ret = CalculateCondExp("4>3 | 5>=4")
	assert.Equal(t, want, ret)

	ret = CalculateCondExp("4>3")
	assert.Equal(t, want, ret)
}

func Test_priority(t *testing.T) {
	var (
		lvl1 = 1
		lvl2 = 2
		lvl3 = 3
		lvl0 = 0

		add      = "+"
		minus    = "-"
		multiple = "*"
		divide   = "/"
		power    = "^"
		other    = "&"
	)

	ret := priority(add[0])
	assert.Equal(t, lvl1, ret)

	ret = priority(minus[0])
	assert.Equal(t, lvl1, ret)

	ret = priority(multiple[0])
	assert.Equal(t, lvl2, ret)

	ret = priority(divide[0])
	assert.Equal(t, lvl2, ret)

	ret = priority(power[0])
	assert.Equal(t, lvl3, ret)

	ret = priority(other[0])
	assert.Equal(t, lvl0, ret)

}

func Test_convertToSuffixExpress(t *testing.T) {
	var (
		expr     = "9+(3-1)*3+10/2"
		expected = []string{
			"9", "3", "1", "-", "3", "*", "+", "10", "2", "/", "+",
		}
	)

	ret, _ := convertToSuffixExpress(expr)
	assert.Equal(t, expected, ret)
}

func Test_calc(t *testing.T) {
	var (
		sufixE = []string{
			"9", "3", "1", "-", "3", "*", "+", "10", "2", "/", "+",
		}
	)

	_, err := calc(sufixE)
	assert.Nil(t, err)
}

func TestStack_IsEmpty(t *testing.T) {
	var (
		s        = &Stack{}
		expected = true
	)
	ret := s.IsEmpty()
	assert.Equal(t, expected, ret)
}

func TestStack_Top(t *testing.T) {
	var (
		s1 = &Stack{}

		s2 = &Stack{
			data: [1024]string{
				"a", "b", "c",
			},
			top: 3,
		}
	)
	_, err := s1.Top()
	assert.NotNil(t, err)

	_, err = s2.Top()
	assert.Nil(t, err)
}

func TestStack_Push(t *testing.T) {
	var (
		s = &Stack{}
	)

	s.Push("a")
	assert.Nil(t, nil)
}

func TestStack_Pop(t *testing.T) {
	var (
		s1 = &Stack{}
		s2 = &Stack{
			data: [1024]string{
				"a", "b", "c", "d",
			},
			top: 3,
		}
	)

	_, err := s1.Pop()
	assert.NotNil(t, err)

	_, err = s2.Pop()
	assert.Nil(t, err)
}

func Test_getANDResult(t *testing.T) {
	var (
		exp      = "4<3 & 5>4"
		expected = false
	)

	ret := getANDResult(exp)
	assert.Equal(t, expected, ret)
}

func Test_getSingleCondResult(t *testing.T) {
	var (
		exp      = "4<3"
		expected = false
	)

	ret := getSingleCondResult(exp)
	assert.Equal(t, expected, ret)
}

func Test_scopeCondResult(t *testing.T) {
	var (
		exp      = "2∈[1, 5]"
		expected = true
	)

	ret := scopeCondResult(exp)
	assert.Equal(t, expected, ret)
}

