package utils

import (
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestParse2Map(t *testing.T) {
	orgJson := `{
    	"sysctl": {
    	    "kernel.hung_task_timeout_secs": {
    	        "dtype": "int",
    	        "value": 600
    	    }
    	}
    }`

	key := "sysctl"
	want := map[string]interface{}{
		"kernel.hung_task_timeout_secs": map[string]interface{}{
			"dtype": "int",
			"value": float64(600),
		},
	}

	ret := Parse2Map(key, []byte(orgJson))
	assert.Equal(t, want, ret)
}

func TestParseKey(t *testing.T) {
	orgJson := `{
    	        "dtype": "int",
    	        "value": 600
        }`
	want := float64(600)
	ret, _ := ParseKey("value", []byte(orgJson))
	assert.Equal(t, want, ret)
}

func TestMap2Struct(t *testing.T) {
	var demo = struct {
		Dtype string `json:"dtype"`
		Value int    `json:"value"`
	}{}
	src := map[string]interface{}{
		"dtype": "int",
		"value": 600,
	}
	ret := Map2Struct(src, &demo)
	assert.Nil(t, ret)
}

func TestInterface2Map(t *testing.T) {
	orgJson := `{
    	"sysctl": {
    	    "kernel.hung_task_timeout_secs": {
    	        "dtype": "int",
    	        "value": 600
    	    }
    	}
    }`
	ret, err := Interface2Map([]byte(orgJson))
	assert.Nil(t, err)
	assert.NotNil(t, ret)
}

func TestStruct2Map(t *testing.T) {
	var demo struct {
		Dtype string `json:"dtype"`
		Value int    `json:"value"`
	}

	demo.Value = 600
	demo.Dtype = "int"
	_, err := Struct2Map(demo)
	assert.Nil(t, err)

}

func TestParse2Struct(t *testing.T) {
	key := "kernel"
	body := map[string]interface{}{
		"kernel": map[string]interface{}{
			"dtype": "int",
			"value": 600,
		},
	}
	var dest = struct {
		Dtype string `json:"dtype"`
		Value int    `json:"value"`
	}{}
	err := Parse2Struct(key, body, &dest)
	assert.Nil(t, err)
}

func Test_change2Map(t *testing.T) {
	var (
		nilSrc map[string]map[string]interface{}
		dbMap  = map[string]map[string]interface{}{
			"sysctl": {
				"kernel.hung_task_timeout_secs": map[string]interface{}{
					"dtype": "int",
					"value": 600,
				},
			},
		}
	)

	got := change2Map(nilSrc)
	assert.Nil(t, got)

	got = change2Map(dbMap)
	assert.NotNil(t, got)
}

