package modules

import (
	"github.com/stretchr/testify/assert"
	"testing"
)

func TestTuner_analyseBestResult(t *testing.T) {
	var (
		tuner = &Tuner{
			feedbackScore: map[string][]float32{
				"aaa": {
					float32(21.7),
					float32(22.1),
				},
			},
			Benchmark: Benchmark{
				SortedItems: []string{
					"aaa",
				},
			},
			bestInfo: Configuration{Score: map[string]ItemDetail{
				"aaa": {
					Baseline: []float32{
						float32(12.3),
						float32(12.5),
					},
				},
			}},
		}
	)

	InitNodesTest()
	ret := tuner.analyseBestResult()
	assert.Empty(t, ret)
}

func TestTuner_analyseResult(t *testing.T) {
	var (
		tuner = &Tuner{
			feedbackScore: map[string][]float32{
				"aaa": {
					float32(21.7),
					float32(22.1),
				},
			},
			Benchmark: Benchmark{
				SortedItems: []string{
					"aaa",
				},
			},
			bestInfo: Configuration{Score: map[string]ItemDetail{
				"aaa": {
					Baseline: []float32{
						float32(12.3),
						float32(12.5),
					},
				},
			}},
		}
	)

	InitNodesTest()
	ret := tuner.analyseResult()
	assert.Empty(t, ret)
}

func Test_getBestRatio(t *testing.T) {
	var (
		info = ItemDetail{
			Baseline: []float32{
				float32(12.3),
				float32(12.5),
			},
		}

		currentScore = []float32{
			float32(21.7),
			float32(22.1),
		}

		verbose = false

		name = "aaa"
	)

	ret := getBestRatio(info, currentScore, verbose, name)
	assert.Equal(t, "", ret)
}

func Test_getRatio(t *testing.T) {
	var (
		info = ItemDetail{
			Baseline: []float32{
				float32(12.3),
				float32(12.5),
			},
			Value: float32(17),
		}
		verbose = true
		name    = "aaa"
	)

	ret := getRatio(info, verbose, name)
	assert.NotEmpty(t, ret)

}

func Test_sprintRatio(t *testing.T) {
	var (
		info = ItemDetail{
			Negative: true,
			Weight:   float32(25),
		}
		verbose bool
		name    = "aaa"
		score   = float32(-27)
		average = float32(25)
	)
	got := sprintRatio(info, verbose, name, score, average)
	assert.NotEmpty(t, got)
}
