package modules

import (
	"keentune/daemon/common/config"
	"sync"
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestGroup_Configure(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	var (
		gp = Group{
			IPs: []string{
				"localhost",
			},
			Params:      []config.DBLMap{},
			Port:        "9873",
			ReadOnly:    true,
			Dump:        Configuration{},
			MergedParam: nil,
			AllowUpdate: map[string]bool{
				"localhost": true,
			},
			GroupName: "",
			GroupNo:   1,
		}

		req = request{
			ip: "localhost",
			body: map[string]interface{}{
				"sysctl": map[string]interface{}{
					"vm.dirty_ratio": map[string]interface{}{
						"dtype": "int",
					},
				},
			},
		}
	)

	_, err := gp.Configure(req)
	assert.NotNil(t, err)

}

func TestGroup_Get(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	var (
		gp = &Group{
			IPs: []string{
				"localhost",
			},
			Params: []config.DBLMap{
				{},
				{
					"sysctl": map[string]interface{}{
						"vm.dirty_ratio": map[string]interface{}{
							"dtype": "int",
						},
					},
				},
			},
			Port:     "9873",
			ReadOnly: true,
			MergedParam: map[string]interface{}{
				"sysctl": map[string]interface{}{
					"vm.dirty_ratio": map[string]interface{}{
						"dtype": "int",
					},
				},
			},
			AllowUpdate: map[string]bool{
				"localhost": true,
			},
			GroupNo: 1,
		}

		req = request{
			ip: "localhost",
		}
	)

	_, err := gp.Get(req)
	assert.Nil(t, err)

}

func TestGroup_Set(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	var (
		gp = Group{
			IPs: []string{
				"localhost",
			},
			Params: []config.DBLMap{
				{
					"sysctl": map[string]interface{}{
						"vm.dirty_ratio": map[string]interface{}{
							"dtype": "int",
						},
					},
				},
			},
			Port: "9873",
			AllowUpdate: map[string]bool{
				"localhost": true,
			},
			GroupNo: 1,
		}

		req = request{
			ip: "localhost",
			body: map[string]interface{}{
				"sysctl": map[string]interface{}{
					"vm.dirty_ratio": map[string]interface{}{
						"dtype": "int",
					},
				},
			},
		}
	)

	req.params = []map[string]interface{}{
		{"sysctl": map[string]interface{}{
			"vm.dirty_ratio": map[string]interface{}{
				"dtype": "int",
			},
		},
		},
	}

	_, err := gp.Set(req)
	assert.NotNil(t, err)
}

func TestGroup_newRequester(t *testing.T) {
	InitNodesTest()
	var (
		gp = Group{
			IPs: []string{
				"localhost",
			},
			Params: []config.DBLMap{
				{
					"sysctl": map[string]interface{}{
						"vm.dirty_ratio": map[string]interface{}{
							"dtype": "int",
						},
					},
				},
			},
		}
	)

	ret := gp.newRequester(1)
	assert.NotNil(t, ret)
}

func TestTuner_apply(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	var (
		tuner = &Tuner{
			ReadConfigure: true,
			Group: []Group{
				{
					IPs: []string{
						"localhost",
					},
					Params: []config.DBLMap{
						{},
						{
							"sysctl": map[string]interface{}{
								"vm.dirty_ratio": map[string]interface{}{
									"dtype": "int",
								},
							},
						},
					},
					Port: "9873",
					MergedParam: map[string]interface{}{
						"sysctl": map[string]interface{}{
							"vm.dirty_ratio": map[string]interface{}{
								"dtype": "int",
							},
						},
					},
					AllowUpdate: map[string]bool{
						"localhost": true,
					},
					GroupNo: 1,
				},
			},
		}

		wg                 = new(sync.WaitGroup)
		targetFinishStatus = make([]string, 4)
		req                = request{
			ip:      "localhost",
			id:      1,
			groupID: 0,
		}
	)

	wg.Add(1)
	err := tuner.apply(wg, targetFinishStatus, req)
	assert.Nil(t, err)
}

func TestTuner_configure(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	var (
		tuner = &Tuner{
			ReadConfigure: true,
			Group: []Group{
				{
					IPs: []string{
						"localhost",
					},
					Params: []config.DBLMap{
						{},
						{
							"sysctl": map[string]interface{}{
								"vm.dirty_ratio": map[string]interface{}{
									"dtype": "int",
								},
							},
						},
					},
					Port: "9873",
					MergedParam: map[string]interface{}{
						"sysctl": map[string]interface{}{
							"vm.dirty_ratio": map[string]interface{}{
								"dtype": "int",
							},
						},
					},
					AllowUpdate: map[string]bool{
						"localhost": true,
					},
					GroupNo: 1,
				},
			},
		}
	)

	err := tuner.configure()
	assert.Nil(t, err)
}

func TestTuner_getConfigure(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	var (
		tuner = &Tuner{
			Group: []Group{
				{
					IPs: []string{
						"localhost",
					},
					Params: []config.DBLMap{
						{},
						{
							"sysctl": map[string]interface{}{
								"vm.dirty_ratio": map[string]interface{}{
									"dtype": "int",
								},
							},
						},
					},
					Port: "9873",
					MergedParam: map[string]interface{}{
						"sysctl": map[string]interface{}{
							"vm.dirty_ratio": map[string]interface{}{
								"dtype": "int",
							},
						},
					},
					AllowUpdate: map[string]bool{
						"localhost": true,
					},
					GroupNo: 1,
				},
			},
		}
	)

	err := tuner.getConfigure()
	assert.Nil(t, err)
}

func TestTuner_setConfigure(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	var (
		tuner = &Tuner{
			Group: []Group{
				{
					IPs: []string{
						"localhost",
					},
					Params: []config.DBLMap{
						{},
						{
							"sysctl": map[string]interface{}{
								"vm.dirty_ratio": map[string]interface{}{
									"dtype": "int",
								},
							},
						},
					},
					Port: "9873",
					MergedParam: map[string]interface{}{
						"sysctl": map[string]interface{}{
							"vm.dirty_ratio": map[string]interface{}{
								"dtype": "int",
							},
						},
					},
					AllowUpdate: map[string]bool{
						"localhost": true,
					},
					GroupNo: 1,
				},
			},
		}
	)

	err := tuner.setConfigure()
	assert.NotNil(t, err)
}
