/*
It is mainly used to assemble and transform the data used for restful request or response with other components.
*/

package modules

import (
	"keentune/daemon/common/config"
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestTuner_initParams(t *testing.T) {
	var (
		tuner = &Tuner{}
	)

	InitNodesTest()
	config.KeenTune.Group[0].Domains = []string{"sysctl"}
	config.KeenTune.TargetSetTimeout = 1

	ret := tuner.initParams()
	assert.Nil(t, ret)
}

func Test_getInitParam(t *testing.T) {
	InitNodesTest()
	var (
		groupId    = 1
		params     = config.KeenTune.Group[0].ParamMap
		brainParam = make([]Parameter, 0)
		target     = new(Group)
	)

	ret := getInitParam(groupId, params, &brainParam, target)
	assert.Nil(t, ret)

}

func Test_deepCopy(t *testing.T) {
	var (
		origin = map[string]interface{}{
			"aaa": "ok",
			"bbb": "not ok",
		}
	)
	ret := deepCopy(origin)
	assert.NotNil(t, ret)
}

func TestTuner_getBrainInitParams(t *testing.T) {
	var (
		tuner = &Tuner{
			Group: []Group{
				{},
			},
			BrainParam: []Parameter{
				{},
				{
					DomainName: "sysctl",
					ParaName:   "vm.page-cluster@group-1",
					Scope: []interface{}{
						0,
						8,
					},
					Dtype: "int",
					Value: 5,
					Step:  1,
					Base:  "6",
				},
			},
		}
	)

	InitNodesTest()
	tuner.Group[0].Params = config.KeenTune.Group[0].ParamMap

	ret := tuner.getBrainInitParams()
	assert.NotNil(t, ret)
}

func Test_parseBrainName(t *testing.T) {
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.Group = []config.Group{
		{
			GroupName: "target-group-1",
		},
	}

	originName := "vm.page-cluster@group-1"
	_, _, err := parseBrainName(originName)
	assert.Nil(t, err)
}

func TestGroup_getBase(t *testing.T) {
	var (
		gp = &Group{
			Params: []config.DBLMap{
				{},
				{
					"sysctl": {
						"vm.page-cluster": map[string]interface{}{
							"domain": "sysctl",
							"range": []int{
								0, 8,
							},
							"dtype": "int",
							"step":  1,
							"base":  "6",
							"value": 5,
						},
					},
				},
			},
		}
		domain = "sysctl"
		name   = "vm.page-cluster"
	)
	_, err := gp.getBase(domain, name)
	assert.Nil(t, err)
}

func TestTuner_parseAcquireParam(t *testing.T) {
	var (
		tuner = &Tuner{
			Name:      "aaa",
			Iteration: 1,
			Group: []Group{
				{
					Params: []config.DBLMap{
						{},
						{
							"sysctl": {
								"vm.page-cluster": map[string]interface{}{
									"domain": "sysctl",
									"range": []int{
										0, 8,
									},
									"dtype": "int",
									"step":  1,
									"base":  "6",
									"value": 5,
								},
							},
						},
					},
				},
			},
		}
		resp = ReceivedConfigure{
			Candidate: []Parameter{
				{
					DomainName: "sysctl",
					ParaName:   "vm.page-cluster@group-1",
					Scope: []interface{}{
						0,
						8,
					},
					Dtype: "int",
					Value: 7,
					Step:  1,
					Base:  "6",
				},
			},
			Iteration: 1,
			Budget:    1,
		}
	)

	InitNodesTest()
	ret := tuner.parseAcquireParam(resp)

	assert.Nil(t, ret)
}

func TestTuner_parseBestParam(t *testing.T) {
	var (
		tuner = &Tuner{
			bestInfo: Configuration{
				Parameters: []Parameter{
					{
						DomainName: "sysctl",
						ParaName:   "vm.page-cluster@group-1",
						Scope: []interface{}{
							0,
							8,
						},
						Dtype: "int",
						Value: 7,
						Step:  1,
						Base:  "6",
					},
				},
			},
			Group: []Group{
				{
					Params: []config.DBLMap{
						{},
						{
							"sysctl": {
								"vm.page-cluster": map[string]interface{}{
									"domain": "sysctl",
									"range": []int{
										0, 8,
									},
									"dtype": "int",
									"step":  1,
									"base":  "6",
									"value": 5,
								},
							},
						},
					},
				},
			},
		}
	)

	InitNodesTest()
	ret := tuner.parseBestParam()

	assert.Nil(t, ret)
}

func TestGroup_updateParams(t *testing.T) {
	var (
		gp = &Group{
			Params: []config.DBLMap{
				{},
				{
					"sysctl": {
						"vm.page-cluster": map[string]interface{}{
							"domain": "sysctl",
							"range": []int{
								0, 8,
							},
							"dtype": "int",
							"step":  1,
							"base":  "6",
							"value": 5,
						},
					},
				},
			},
		}
		params = map[string]Parameter{
			"vm.page-cluster": {
				DomainName: "sysctl",
				ParaName:   "vm.page-cluster",
				Value:      6,
			},
		}
	)
	err := gp.updateParams(params)
	assert.Nil(t, err)
}

func TestGroup_updateValue(t *testing.T) {
	var (
		gp = &Group{
			Params: []config.DBLMap{
				{},
				{
					"sysctl": {
						"vm.page-cluster": map[string]interface{}{
							"domain": "sysctl",
							"range": []int{
								0, 8,
							},
							"dtype": "int",
							"step":  1,
							"base":  "6",
							"value": 5,
						},
					},
				},
			},
		}
		param = Parameter{
			DomainName: "sysctl",
			ParaName:   "vm.page-cluster",
			Value:      6,
		}
	)
	err := gp.updateValue(param)
	assert.Nil(t, err)
}

func TestGroup_mergeParam(t *testing.T) {
	var (
		gp = &Group{
			Params: []config.DBLMap{
				{},
				{
					"sysctl": {
						"vm.page-cluster": map[string]interface{}{
							"domain": "sysctl",
							"range": []int{
								0, 8,
							},
							"dtype": "int",
							"step":  1,
							"base":  "6",
							"value": 5,
						},
					},
				},
			},
		}
	)

	gp.mergeParam()
	assert.Nil(t, nil)
}

func TestGroup_applyReq(t *testing.T) {
	var (
		gp = &Group{
			Params: []config.DBLMap{
				{},
				{
					"sysctl": {
						"vm.page-cluster": map[string]interface{}{
							"domain": "sysctl",
							"range": []int{
								0, 8,
							},
							"dtype": "int",
							"step":  1,
							"base":  "6",
							"value": 5,
						},
					},
				},
			},
		}
		param = Parameter{}
		ip    = "localhost"
	)
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.Port = "9871"
	config.KeenTune.IPMap = map[string]int{
		"localhost": 1,
	}

	ret := gp.applyReq(ip, param)
	assert.NotNil(t, ret)
}

func TestGroup_updateDump(t *testing.T) {
	var (
		gp = &Group{
			Dump: Configuration{
				Parameters: []Parameter{
					{
						DomainName: "sysctl",
						ParaName:   "vm.page-cluster",
						Value:      6,
					},
				},
			},
		}

		param = map[string]Parameter{
			"vm.page-cluster": {
				DomainName: "sysctl",
				ParaName:   "vm.page-cluster",
				Value:      8,
			},
		}
	)

	gp.updateDump(param)
	assert.Nil(t, nil)
}

func TestTuner_initProfiles(t *testing.T) {
	var (
		tuner = &Tuner{
			Setter: Setter{
				Group: []bool{true},
				ConfFile: []string{
					"cpu_high_load.conf",
				},
			},
		}
	)

	InitNodesTest()
	err := tuner.initProfiles()
	assert.NotNil(t, err)
}

func TestGroup_getConfigParam(t *testing.T) {
	var (
		gp = &Group{
			IPs: []string{
				"localhost",
			},
		}
		param = "/etc/keentune/keentuned/profile/basic/cpu_high_load.conf"
	)
	InitNodesTest()
	_, err := gp.getConfigParam(param)
	assert.Nil(t, err)
}

func TestGroup_getConfDomain(t *testing.T) {
	var (
		gp = &Group{
			IPs:  []string{"localhost"},
			Port: "9873",
		}
		param = map[string]map[string]interface{}{
			"sysctl": {
				"vm.page-cluster": map[string]interface{}{
					"domain": "sysctl",
					"range": []int{
						0, 8,
					},
					"dtype": "int",
					"step":  1,
					"base":  "6",
					"value": 5,
				},
			},
		}
		abnormal = &ABNLResult{}
	)
	err := gp.getConfDomain(param, abnormal)
	assert.Nil(t, err)
}

func TestGroup_deleteUnAVLConf(t *testing.T) {
	var (
		gp = &Group{
			Params: []config.DBLMap{
				{},
				{
					"sysctl": {
						"vm.page-cluster": map[string]interface{}{
							"domain": "sysctl",
							"range": []int{
								0, 8,
							},
							"dtype": "int",
							"step":  1,
							"base":  "6",
							"value": 5,
						},
					},
				},
			},
			MergedParam: map[string]interface{}{},
		}

		params = []map[string]map[string]string{
			{
				"sysctl": map[string]string{
					"vm.page-cluster": "value not ok",
				},
			},
		}
	)
	_, ret := gp.deleteUnAVLConf(params)
	assert.Equal(t, WARNING, ret)
}

func TestGroup_tidyUnavailableParams(t *testing.T) {
	var (
		domain = "sysctl"
		param  = map[string]string{
			"vm.page-cluster": "value not ok",
		}

		gp = &Group{
			Params: []config.DBLMap{
				{},
				{
					"sysctl": {
						"vm.page-cluster": map[string]interface{}{
							"domain": "sysctl",
							"range": []int{
								0, 8,
							},
							"dtype": "int",
							"step":  1,
							"base":  "6",
							"value": 5,
						},
					},
				},
			},
			UnAVLParams: map[string]map[string]string{
				domain: param,
			},
		}

		warning = new(string)
	)

	ret := gp.tidyUnavailableParams(param, domain, warning)
	assert.NotEmpty(t, ret)
}
