package modules

import (
	"github.com/stretchr/testify/assert"
	"keentune/daemon/common/config"
	"keentune/daemon/common/log"
	"testing"
)

func TestTuner_getBest(t *testing.T) {
	var (
		tuner = &Tuner{
			Name:    "aaa",
			Flag:    "tuning",
			logName: log.ParamTune,
		}
	)

	InitNodesTest()

	err := tuner.getBest()
	assert.NotNil(t, err)
}

func TestTuner_verifyBest(t *testing.T) {
	var (
		tuner = &Tuner{
			Name:    "aaa",
			Flag:    "tuning",
			logName: log.ParamTune,
			Group: []Group{
				{
					Params: []config.DBLMap{
						{
							"sysctl": {
								"vm.page-cluster": map[string]interface{}{
									"domain": "sysctl",
									"range": []int{
										0, 8,
									},
									"dtype": "int",
									"step":  1,
									"base":  "6",
									"value": 5,
								},
							},
						},
					},
				},
			},
		}
	)

	InitNodesTest()
	InitHttpChan()
	config.KeenTune.AfterRound = 1
	err := tuner.verifyBest()
	assert.NotNil(t, err)
}

func TestTuner_dumpBest(t *testing.T) {
	var (
		tuner = &Tuner{
			Name:    "aaa",
			Flag:    "tuning",
			logName: log.ParamTune,
		}
	)

	InitNodesTest()
	config.KeenTune.BestDump = true

	err := tuner.dumpBest()
	assert.NotNil(t, err)
}

