package modules

import (
	"encoding/json"
	"keentune/daemon/common/config"
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestTuner_isInterrupted(t *testing.T) {
	var (
		tuner = &Tuner{}
	)

	tuner.isInterrupted()
	assert.Nil(t, nil)
}

func TestRollback(t *testing.T) {
	InitNodesTest()
	var (
		logName  = ""
		callType = "rollback"
	)

	_, err := Rollback(logName, callType)
	assert.Nil(t, err)
}

func TestGroup_concurrentSuccess(t *testing.T) {
	InitNodesTest()
	var (
		gp  = &Group{}
		uri = "rollback"
		req = map[string]interface{}{
			"domains": []string{"sysctl"},
			"all":     false,
		}
	)

	gp.IPs = config.KeenTune.Group[0].IPs
	gp.Port = config.KeenTune.Group[0].Port

	_, ret := gp.concurrentSuccess(uri, req)
	assert.Equal(t, SUCCESS, ret)
}

func Test_callRollback(t *testing.T) {
	InitNodesTest()
	var (
		method = "POST"
		uri    = "localhost:9873/rollback"
		req    = map[string]interface{}{
			"domains": []string{"sysctl"},
			"all":     false,
		}
	)

	_, ret := callRollback(method, uri, req)
	assert.Equal(t, SUCCESS, ret)
}

func Test_parseStatusCode(t *testing.T) {
	msgStr := `{
    "cpu": {
        "suc": true,
        "msg": "backup file /var/keentune/target/backup/Cpu.json do not exists."
    },
    "disk": {
        "suc": true,
        "msg": "backup file /var/keentune/target/backup/Disk.json do not exists."
    },
    "sysctl": {
        "suc": true,
        "msg": "backup file /var/keentune/target/backup/Sysctl.json do not exists."
    }
}`

	msg := map[string]interface{}{}

	json.Unmarshal([]byte(msgStr), &msg)
	ret := parseStatusCode(msg)
	assert.Equal(t, WARNING, ret)
}

func Test_parseMsg(t *testing.T) {
	var msg = `{
    "cpu": {
        "suc": true,
        "msg": "backup file /var/keentune/target/backup/Cpu.json do not exists."
    },
    "disk": {
        "suc": true,
        "msg": "backup file /var/keentune/target/backup/Disk.json do not exists."
    },
    "sysctl": {
        "suc": true,
        "msg": "backup file /var/keentune/target/backup/Sysctl.json do not exists."
    }
}`
	got := parseMsg(msg)
	assert.NotEmpty(t, got)
}

func TestTuner_original(t *testing.T) {
	InitNodesTest()

	var (
		tuner = &Tuner{
			Group: []Group{
				{
					IPs:  []string{"localhost"},
					Port: "9873",
				},
			},
		}
	)

	err := tuner.original()
	assert.Nil(t, err)
}

func Test_assertIgnoreRollbackErr(t *testing.T) {
	var msg = ""
	got := assertIgnoreRollbackErr(msg)
	assert.Equal(t, false, got)
}
