package modules

import (
	"encoding/json"
	"testing"

	"github.com/stretchr/testify/assert"
)

var configReq = `{
	"data": {
		"sysctl": {
			"fs.aio-max-nr": {
				"dtype": "int",
				"value": 6166430
			},
			"fs.file-max": {
				"dtype": "int",
				"value": 7828086
			},
			"fs.inotify.max_user_instances": {
				"dtype": "int",
				"value": 11733
			},
			"fs.inotify.max_user_watches": {
				"dtype": "int",
				"value": 465548
			},
			"vm.swappiness": {
				"dtype": "int",
				"value": 12
			},
			"vm.vfs_cache_pressure": {
				"dtype": "int",
				"value": 368
			},
			"vm.watermark_scale_factor": {
				"dtype": "int",
				"value": 762
			},
			"vm.zone_reclaim_mode": {
				"dtype": "string",
				"value": "2"
			}
		}
	},
	"readonly": false,
	"resp_ip": "localhost",
	"resp_port": "9871",
	"target_id": 1
}`

func TestConfiguration_Save(t *testing.T) {
	var (
		conf = Configuration{
			Round: 1,
		}
		fileName = "aaa"
		suffix   = "_best.json"
	)
	InitFileTest()

	err := conf.Save(fileName, suffix)
	assert.Nil(t, err)
}

func Test_target_collectParam(t *testing.T) {
	var paramStr = `
	{
		"fs.aio-max-nr": {
			"value": "5529600",
			"suc":   true,
			"msg":   "",
		},
		"fs.file-max": {
			"value": "2048000",
			"suc":   true,
			"msg":   "",
		},
		"fs.inotify.max_user_instances": {
			"value": "53952",
			"suc":   true,
			"msg":   "",
		},
	}
	`
	var paramsRes map[string]ParamResult
	json.Unmarshal([]byte(paramStr), &paramsRes)
	var (
		tg = target{
			desSeparator: " ",
		}
		data = map[string]Response{
			"sysctl": Response{
				ParamsResult: paramsRes,

				Suc: true,
				Msg: "",
			},
		}
	)

	_, _, err := tg.collectParam(data)
	assert.NotNil(t, err)
}

func Test_target_GetApplyResult(t *testing.T) {
	var (
		tg = target{
			desSeparator: " ",
			respBody: []byte(`{
	"sysctl": {
		"param_result": {
			"kernel.core_uses_pid": {
				"suc": true,
				"msg": "1"
			},
			"fs.file-max": {
				"suc": true,
				"msg": "13152041"
			}
		},
		"suc": true,
		"msg": ""
	}
}`),
			ipIndex: 1,
			host:    "localhost:9873",
		}
	)

	InitNodesTest()
	InitHttpChan()

	_, _, err := tg.GetApplyResult()
	assert.Nil(t, err)
}

func TestConfigure(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	var (
		req   = configReq
		host  = "localhost:9873"
		ipIdx = 1
	)

	_, err := Configure(req, host, ipIdx)
	assert.NotNil(t, err)
}

func Test_newTarget(t *testing.T) {
	var (
		req            = configReq
		host           = "localhost:9873"
		ipIdx          = 1
		desSep, tabSep = "\t\t", "\t\t\t"
	)

	ret := newTarget(ipIdx, host, req, desSep, tabSep)
	assert.NotNil(t, ret)
}

func Test_target_configure(t *testing.T) {
	var (
		tg = target{
			desSeparator: " ",
			ipIndex:      1,
			host:         "localhost:9873",
			reqBody:      configReq,
		}
	)

	InitNodesTest()
	InitHttpChan()

	_, _, err := tg.configure()
	assert.NotNil(t, err)
}
