package modules

import (
	"github.com/stretchr/testify/assert"
	"strings"
	"testing"
)

func Test_convertDomain(t *testing.T) {
	var (
		domainFind    = "scheduler_amd"
		domainNotFind = "scheduler"
	)

	ret1 := convertDomain(domainFind)
	assert.NotEmpty(t, ret1)
	ret2 := convertDomain(domainNotFind)
	assert.NotEmpty(t, ret2)
}

func Test_replaceVariables(t *testing.T) {
	var (
		variableMap = map[string]string{
			"isolated_cores": "3",
		}
		line = "${isolated_cores}"
	)

	got := replaceVariables(variableMap, line)
	expect := true
	assert.Equal(t, expect, !strings.Contains(got, "{"))
}

func Test_isExpectedRegx(t *testing.T) {
	var (
		orgStr = "__ENV-LIMITATION = #!uname_arch#= aarch64 & #!thunderx_cpu_info# = ${thunderx_cpuinfo_regex}"
	)

	ret := isExpectedRegx(orgStr)
	expect := false
	assert.Equal(t, expect, ret)
}

func Test_getCondResultWithVar(t *testing.T) {
	var (
		expressOr    = "2=1|2<4"
		expressAnd   = "3!=4 & 5<6"
		expressOther = "CPU part : 0x08516 = thunderx_cpuinfo_regex"
	)
	expect := false
	got := getCondResultWithVar(expressOr)
	assert.Equal(t, true, got)
	got1 := getCondResultWithVar(expressAnd)
	assert.Equal(t, true, got1)
	got2 := getCondResultWithVar(expressOther)
	assert.Equal(t, expect, got2)
}

func Test_calculateSingleCond(t *testing.T) {
	var (
		expressOther = "CPU part : 0x08516 = thunderx_cpuinfo_regex"
	)

	got := calculateSingleCond(expressOther)
	assert.Equal(t, false, got)
}

func Test_calculateByLogic(t *testing.T) {
	var (
		expressAnd = "3!=4 & 5<6"
		logic      = "and"
		expressOr  = "3!=3 | 5<6"
		logicOr    = "or"
	)

	got := calculateByLogic(expressAnd, logic)
	assert.Equal(t, true, got)

	got = calculateByLogic(expressOr, logicOr)
	assert.Equal(t, true, got)
}

