package modules

import (
	"github.com/stretchr/testify/assert"
	"regexp"
	"testing"
)

func Test_calculateCondition(t *testing.T) {
	var (
		content = "#!CPU_CORE#=8 & #!MEM_TOTAL# ∈ [29, 32]"
		macros  = []string{"#!cpu_core#"}
		ip      = "localhost"
	)

	_, ret := calculateCondition(content, macros, ip)
	assert.Equal(t, false, ret)
}

func Test_isConditionExp(t *testing.T) {
	var content = `#!CPU_CORE#=8 & #!MEM_TOTAL# ∈ [29, 32]`
	got := isConditionExp(content)
	assert.Equal(t, true, got)
}

func Test_detectConfValue(t *testing.T) {
	var (
		paramName = "__ENV-LIMITATION"
		valueStr  = "#!CPU_CORE#=8 & #!MEM_TOTAL# ∈ [29, 32]"
		ip        = "localhost"
	)
	re, _ := regexp.Compile(defDetectAllReg)

	_, _, err := detectConfValue(re, valueStr, paramName, ip)
	assert.Nil(t, err)
}

func Test_detectSpecVarMap(t *testing.T) {
	InitNodesTest()
	var (
		name      = "innodb_log_file_size"
		ip        = "localhost"
		valuseStr string
	)
	_, _, err := detectSpecVarMap(name, valuseStr, ip)
	assert.Nil(t, err)
}

func Test_isDetectMapString(t *testing.T) {
	var (
		paramName = "innodb_log_file_size"
		valueStr  = "#?innodb_log_file_size#"
	)

	ret := isDetectMapString(paramName, valueStr)
	assert.Equal(t, true, ret)
}

func Test_detect(t *testing.T) {
	var (
		data        = []string{"cpu_core"}
		orgName     = []string{"cpu_core"}
		detectedMap = map[string]string{}
		ip          = "localhost"
	)

	InitNodesTest()

	ret := detect(data, orgName, detectedMap, ip)
	assert.Nil(t, ret)
}

func Test_detectParam(t *testing.T) {
	var (
		param = &Parameter{
			Scope: []interface{}{
				float64(1),
				"#!cpu_core#*2",
			},
		}
	)

	err := detectParam(param)
	assert.Nil(t, err)
}

