package modules

import (
	"os"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
)

func Test_getTuneJobFile(t *testing.T) {
	InitFileTest()
	ret := getTuneJobFile()
	assert.NotEmpty(t, ret)
}

func Test_getSensitizeJobFile(t *testing.T) {
	InitFileTest()
	ret := getSensitizeJobFile()
	assert.NotEmpty(t, ret)
}

func TestTuner_CreateTuneJob(t *testing.T) {
	InitFileTest()
	clearTuneJob()
	defer clearTuneJob()
	var (
		tuner = &Tuner{
			Name:         "aaa",
			MAXIteration: 10,
			StartTime:    time.Now(),
			Algorithm:    "hord",
			Flag:         JobTuning,
		}
	)
	err := tuner.CreateTuneJob()
	assert.Nil(t, err)
}

func TestTuner_backupConfFile(t *testing.T) {
	var (
		tuner = &Tuner{
			Name: "aaa",
			Flag: JobTuning,
		}
	)
	InitFileTest()
	tuner.backupConfFile()
	assert.Nil(t, nil)
}

func TestTuner_updateJob(t *testing.T) {
	var (
		tuner = &Tuner{
			Flag: JobTuning,
			Name: "aaa",
		}

		info = map[int]string{
			TuneNameIdx:   tuner.Name,
			TuneStatusIdx: Finish,
		}
	)
	InitNodesTest()
	tuner.updateJob(info)
	assert.Nil(t, nil)
}

func TestTuner_updateStatus(t *testing.T) {
	var (
		tuner = &Tuner{
			Flag: JobTuning,
			Name: "aaa",
		}
	)
	InitNodesTest()

	tuner.updateStatus(Finish)
	assert.Nil(t, nil)
}

func TestGetRunningTask(t *testing.T) {
	ret := GetRunningTask()
	assert.Empty(t, ret)
}

func TestSetRunningTask(t *testing.T) {
	defer func() {
		os.Remove(activeJobCsv)
	}()

	var (
		class = "tuning"
		name  = "aaa"
	)

	SetRunningTask(class, name)
	assert.Nil(t, nil)
}

func TestClearTask(t *testing.T) {
	ClearTask()
	assert.Nil(t, nil)
}
