package modules

import (
	"github.com/stretchr/testify/assert"
	"keentune/daemon/common/config"
	"keentune/daemon/common/log"
	"testing"
	"time"
)

func TestTuner_loop(t *testing.T) {
	InitNodesTest()
	InitHttpChan()
	defer func() {
		clearTuneJob()
	}()

	var (
		tuner = &Tuner{
			Name:         "aaa",
			MAXIteration: 2,
			Algorithm:    "hord",
			StartTime:    time.Now(),
			Flag:         JobTuning,
			Group: []Group{
				{
					GroupNo: 1,
					IPs:     []string{"localhost"},
					Port:    "9873",
				},
			},
		}
	)
	tuner.CreateTuneJob()

	err := tuner.loop()
	assert.NotEmpty(t, err)
}

func TestTuner_benchmark(t *testing.T) {
	InitNodesTest()
	InitHttpChan()

	var (
		tuner = &Tuner{
			Name:         "aaa",
			MAXIteration: 2,
			Algorithm:    "hord",
			StartTime:    time.Now(),
			Flag:         JobTuning,
			logName:      log.ParamTune,
			Group: []Group{
				{
					GroupNo: 1,
					IPs:     []string{"localhost"},
					Port:    "9873",
					Dump:    Configuration{},
				},
			},
			Benchmark: Benchmark{
				Cmd:      "python3 benchmark/wrk/wrk_http_long.py localhost",
				FilePath: "benchmark/wrk/wrk_http_long.py",
				SortedItems: []string{
					"Latency_90",
					"Latency_99",
					"Requests_sec",
					"Transfer_sec",
				},
				round:   1,
				LogName: log.ParamTune,
				Items: map[string]ItemDetail{
					"Requests_sec": {
						Negative: false,
						Weight:   100,
						Strict:   false,
					},
					"Transfer_sec": {
						Negative: false,
						Weight:   0,
						Strict:   false,
					},
					"Latency_90": {
						Negative: true,
						Weight:   0,
						Strict:   true,
					},
					"Latency_99": {
						Negative: true,
						Weight:   0,
						Strict:   true,
					},
				},
			},
		}
	)

	config.KeenTune.ExecRound = 1

	err := tuner.benchmark()
	assert.NotNil(t, err)
}

