package modules

import (
	"github.com/stretchr/testify/assert"
	"testing"
)

func Test_getMethodReqByNames(t *testing.T) {
	var data = []string{
		"cpu_core",
	}
	ret := getMethodReqByNames(data)
	assert.NotNil(t, ret)
}

func Test_getMethodReqByArg(t *testing.T) {
	var data = map[string]interface{}{
		"cpu_core": methodReq{
			Name: "cpu_core",
			Args: []interface{}{},
		},
	}
	ret1, _ := getMethodReqByArg(data)

	assert.NotNil(t, ret1)
}

func Test_matchString(t *testing.T) {
	var (
		pattern = defFuncWithOneArgReg
		str     = "${f:cpulist_online:${isolated_cores}}"
	)

	ret := matchString(pattern, str)
	assert.Equal(t, true, ret)
}

func Test_getVariableReq(t *testing.T) {
	var (
		lineStr = "isolated_cores_expanded:${f:cpulist_unpack:${isolated_cores}}"
		varMap  = map[string]interface{}{}
	)

	getVariableReq(lineStr, varMap)
	expectLen := 1
	assert.Equal(t, expectLen, len(varMap))
}

func Test_getFuncWithOneArgMethodReq(t *testing.T) {
	var (
		org    = "${f:cpulist_unpack:${isolated_cores}}"
		varMap = map[string]interface{}{}
	)

	getFuncWithOneArgMethodReq(org, varMap)
	expectLen := 0
	assert.Equal(t, expectLen, len(varMap))
}

func Test_getDoubleFuncMethodReq(t *testing.T) {
	org := "${f:strip:${f:exec:mktemp:-d}}"

	ret := getDoubleFuncMethodReq(org)
	expectedName := "strip"
	assert.Equal(t, expectedName, ret.Name)
}

func Test_requestAllVariables(t *testing.T) {
	var (
		destMap = map[string]string{}
		data    = map[string]interface{}{
			"cpu_core": methodReq{
				Name: "cpu_core",
				Args: []interface{}{},
			},
		}
	)

	err := requestAllVariables(destMap, data)
	assert.Nil(t, err)
}

func TestGetEnvCondition(t *testing.T) {
	var (
		param = []map[string]map[string]string{
			{
				"ecs/ecs-guest": map[string]string{
					"os_release": "Alibaba Cloud Linux release 3",
					"virt":       ".+",
				},
			},
			{
				"tuned/atomic-guest": map[string]string{
					"system": ".*atomic.*",
					"virt":   ".+",
				},
			},
		}

		host = "localhost:9873"
	)

	_, err := GetEnvCondition(param, host)
	assert.Nil(t, err)
}

func Test_parseEnvCondReq(t *testing.T) {
	param := []map[string]map[string]string{
		{
			"ecs/ecs-guest": map[string]string{
				"os_release": "Alibaba Cloud Linux release 3",
				"virt":       ".+",
			},
		},
		{
			"tuned/atomic-guest": map[string]string{
				"system": ".*atomic.*",
				"virt":   ".+",
			},
		},
	}

	_, _, err := parseEnvCondReq(param)
	assert.Nil(t, err)
}

