package modules

import (
	"encoding/json"
	"keentune/daemon/common/config"
	"keentune/daemon/common/log"
)

func InitHttpChan() {
	config.IsInnerBenchRequests = make([]bool, 4)
	config.IsInnerApplyRequests = make([]bool, 4)
	config.IsInnerSensitizeRequests = make([]bool, 4)

	config.ApplyResultChan = make([]chan []byte, 4)
	config.ApplyResultChan[1] = make(chan []byte, 1)

	config.BenchmarkResultChan = make([]chan []byte, 4)
	config.BenchmarkResultChan[1] = make(chan []byte, 1)

	config.ProgramNeedExit = make(chan bool, 1)

	config.ServeTerminate = make(chan bool, 1)
	config.ClientOffline = make(chan bool, 1)
	config.SensitizeResultChan = make(chan []byte, 1)
}

func InitNodesTest() {
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.LogFileLvl = "INFO"
	config.KeenTune.FileName = "keentuned.log"
	config.KeenTune.Interval = 7
	config.KeenTune.BackupCount = 14
	config.KeenTune.Home = "/etc/keentune/keentuned"
	config.KeenTune.DumpHome = "/var/keentune/keentuned"
	log.Init()

	InitBenchTest()
	InitTargetTest()
	config.RealLocalIP = "localhost"
	config.KeenTune.BrainPort = "9872"
	config.KeenTune.BrainIP = "localhost"
	config.KeenTune.HeartbeatTime = 3
	config.RealLocalIP = "localhost"
	config.KeenTune.Port = "9871"

	config.KeenTune.BaseRound = 1
	config.KeenTune.ExecRound = 1
	config.KeenTune.AfterRound = 1

	config.KeenTune.SensTimeout = 1
	config.KeenTune.TargetSetTimeout = 1
	config.KeenTune.BenchTimeout = 1
}

func InitBenchTest() {
	var benchGp []config.BenchGroup
	benchGp = append(benchGp, config.BenchGroup{
		SrcPort: "9874",
		SrcIPs:  []string{"localhost"},
		DestIP:  "localhost",
	})

	bencIpMap := map[string]int{
		"localhost": 1,
	}
	config.KeenTune.Bench = config.Bench{
		BenchGroup: benchGp,
		BenchIPMap: bencIpMap,
	}
}
func InitTargetTest() {
	var targetGp config.Target
	var paramStr = `{
	"sysctl": {
		"vm.page-cluster": {
			"dtype": "int"
		},
		"vm.stat_interval": {
			"dtype": "int"
		},
		"vm.swappiness": {
			"dtype": "int"
		},
		"vm.vfs_cache_pressure": {
			"dtype": "int"
		},
		"vm.watermark_scale_factor": {
			"dtype": "int"
		},
		"vm.zone_reclaim_mode": {
			"dtype": "string"
		}
	}
}`
	var (
		paramMaps = make([]config.DBLMap, 1)
		params    config.DBLMap
	)

	json.Unmarshal([]byte(paramStr), &params)
	paramMaps = append(paramMaps, params)

	targetGp = config.Target{
		Group: []config.Group{
			{
				IPs:      []string{"localhost"},
				Port:     "9873",
				GroupNo:  1,
				ParamMap: paramMaps,
			},
		},
		IPMap: map[string]int{
			"localhost": 1,
		},
	}

	config.KeenTune.Target = targetGp
}

func InitFileTest() {
	config.KeenTune = new(config.KeentunedConf)
	config.KeenTune.Home = "/etc/keentune/keentuned"
	config.KeenTune.DumpHome = "/var/keentune/keentuned"
}
