package modules

import (
	"github.com/stretchr/testify/assert"
	"keentune/daemon/common/config"
	"keentune/daemon/common/file"
	"os"
	"testing"
	"time"
)

func TestTuner_Train(t *testing.T) {
	defer clearTrainJob()
	InitNodesTest()
	InitHttpChan()
	tuner := &Tuner{
		Name:        "bbb",
		Algorithm:   "Xsen",
		StartTime:   time.Now(),
		Step:        1,
		isSensitize: true,
		Flag:        "training",
		Trainer: Trainer{
			Job:    "bbb",
			Data:   "aaa",
			Trials: 3,
		},
	}

	tuner.Train()
	assert.Nil(t, nil)
}

func TestTuner_CreateTrainJob(t *testing.T) {
	defer clearTrainJob()
	InitNodesTest()
	tuner := &Tuner{
		Name:        "bbb",
		Algorithm:   "Xsen",
		StartTime:   time.Now(),
		Step:        1,
		isSensitize: true,
		Flag:        "training",
		Trainer: Trainer{
			Job:    "bbb",
			Data:   "aaa",
			Trials: 3,
		},
	}

	err := tuner.CreateTrainJob()
	assert.Nil(t, err)
}

func TestTuner_initiateSensitization(t *testing.T) {
	InitNodesTest()
	tuner := &Tuner{
		Name:        "bbb",
		Algorithm:   "Xsen",
		StartTime:   time.Now(),
		Step:        1,
		isSensitize: true,
		Flag:        "training",
		Trainer: Trainer{
			Job:    "bbb",
			Data:   "aaa",
			Trials: 3,
		},
	}

	err := tuner.initiateSensitization()
	assert.Nil(t, err)
}

func TestTuner_getSensitivityResult(t *testing.T) {
	InitNodesTest()
	InitHttpChan()

	tuner := &Tuner{
		Name:        "bbb",
		Algorithm:   "Xsen",
		StartTime:   time.Now(),
		Step:        1,
		isSensitize: true,
		Flag:        "training",
		Trainer: Trainer{
			Job:    "bbb",
			Data:   "aaa",
			Trials: 3,
		},
	}

	_, err := tuner.getSensitivityResult()
	assert.NotNil(t, err)
}

func Test_saveSensitiveResult(t *testing.T) {
	var (
		result = [][]float64{
			{
				float64(1),
			},
			{
				float64(2),
			},
			{
				float64(3),
			},
		}
		header = []string{
			"kernel.numa_balancing@group-1",
		}
		csvFile = "/var/keentune/keentuned/sensitize_workspace/bbb/sensi_result.csv"
	)
	file.CreatCSV(csvFile, header)
	ret := saveSensitiveResult(result, header, csvFile)
	assert.NotNil(t, ret)
}

func Test_initSensitiveTable(t *testing.T) {
	var (
		resultSlice = make([][]string, 2)
		header      = []string{
			"kernel.numa_balancing@group-1",
		}
		col = 3
	)

	initSensitiveTable(col, resultSlice, header)
	assert.NotNil(t, resultSlice[0])
}

func TestTuner_dumpSensitivityResult(t *testing.T) {
	InitNodesTest()
	var (
		tuner      = &Tuner{}
		recordName = "ddd"
		resultMap  = map[string]interface{}{
			"test": "ok",
		}
	)
	err := tuner.dumpSensitivityResult(resultMap, recordName)
	assert.Nil(t, err)
}

func TestTuner_copyKnobsFile(t *testing.T) {
	InitNodesTest()
	var (
		tuner = &Tuner{
			Trainer: Trainer{
				Data: "aaa",
				Job:  "bbb",
			},
		}
	)
	err := tuner.copyKnobsFile()
	assert.NotNil(t, err)
}

func clearTrainJob() {
	os.RemoveAll("/var/keentune/keentuned/sensitize_workspace/bbb")
	file.DeleteRow(config.GetDumpPath(config.SensitizeCsv), "bbb", TrainNameIdx)
	os.Remove("/var/log/keentune/keentune_train_bbb.log")
}
